summaryrefslogtreecommitdiff
path: root/nuttx/net/arp/arp_notify.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/net/arp/arp_notify.c')
-rw-r--r--nuttx/net/arp/arp_notify.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/nuttx/net/arp/arp_notify.c b/nuttx/net/arp/arp_notify.c
index 19e082f22..d2f4c0689 100644
--- a/nuttx/net/arp/arp_notify.c
+++ b/nuttx/net/arp/arp_notify.c
@@ -46,6 +46,7 @@
#include <netinet/in.h>
+#include <nuttx/net/net.h>
#include <arch/irq.h>
#include "arp/arp.h"
@@ -167,7 +168,7 @@ int arp_wait_cancel(FAR struct arp_notify_s *notify)
*
* Assumptions:
* This function is called from ARP send must execute with the network
- * un-locked (interrupts may be disabled to keep the things stable).
+ * locked.
*
****************************************************************************/
@@ -192,11 +193,11 @@ int arp_wait(FAR struct arp_notify_s *notify, FAR struct timespec *timeout)
abstime.tv_nsec -= 1000000000;
}
/* REVISIT: If sem_timedwait() is awakened with signal, we will return
* the wrong error code.
*/
- (void)sem_timedwait(&notify->nt_sem, &abstime);
+ (void)net_timedwait(&notify->nt_sem, &abstime);
ret = notify->nt_result;
/* Remove our wait structure from the list (we may no longer be at the
@@ -192,11 +193,11 @@ int arp_wait(FAR struct arp_notify_s *notify, FAR struct timespec *timeout)
abstime.tv_nsec -= 1000000000;
}
- /* REVISIT: If sem_timedwait() is awakened with signal, we will return
+ /* REVISIT: If net_timedwait() is awakened with signal, we will return
* the wrong error code.
*/